#!/bin/ksh
#set -x
#=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#
#                    WebTop cgi script for PROVISO/WebTop integration
#
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# FileName      : proviso.cgi
# Author        : Vlad Gershkovich
# Date          : 06/20/03
# Subject       :
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Copyright(c) QUALLABY 2001                                       PROVISO 3
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Modifications
# 2008-08-28    : Renamed to proviso.cgi
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

thisFile="$(whence ${0})"
thisDir="$(dirname ${thisFile})"
ARGS="$@"
PROGNAMEfull="${0##*/}"
PROGNAME="${PROGNAMEfull%%.*}"

# a path to a corresponding configuration proviso.cfg file
CFGfile="${thisDir}/${PROGNAME}.cfg"

# field separator used in the configuration proviso.cfg file
CFGsep='|'

# field separator used for the NameValue [NV] pairs as passed by WebTop
# e.g.:        '&<paramName>=<paramValue>&<paramName>=<paramValue>'
NVsep='='

# an absolute path name to awk
AWK='/bin/nawk'

# ------------------------------------------------------------------------
# output message as HTML block to stdout
#
outputHTMLmsg()  # $1 - message to output
{
   cat <<EOF
Content-type: text/html

<html>
<head>
${*}
</head>
</html>
EOF
}


# ------------------------------------------------------------------------
# check if the corresponding configuration file is accessible.
if [ ! -e "${CFGfile}" ] ; then
  echo "${PROGNAMEfull} ERROR: [${CFGfile}] No such file or directory" 2>&1
  outputHTMLmsg "${PROGNAMEfull} ERROR: [${CFGfile}]: No such file or directory <BR>
                 Proviso CGI script configuration file could not be found - see your WebTop administrator to correct the problem."
  exit 1;
fi;

# ------------------------------------------------------------------------
# check if the WebTop's environment variable 'QUERY_STRING' is set.
if [ ! "${QUERY_STRING:-}" ] ; then
  echo "${PROGNAMEfull} ERROR: WebTop's [QUERY_STRING] is not set." 2>&1
  outputHTMLmsg "${PROGNAMEfull} ERROR: WebTop's [QUERY_STRING] is not set. <BR>
                 This indicates a problem with Proviso CGI Tool definitions in <BR>
                 in the WebTop Administration function. <BR>
                 See your WebTop Administrator to correct the problem or contact <BR>
                 Proviso Professional Service."
  exit 1;
fi;

# ------------------------------------------------------------------------

echo "${QUERY_STRING}" | ${AWK} -v FScfg="${CFGsep}" -v FSdata='&'  -v FSvalue="\\${NVsep}" -v CFGfile="${CFGfile}" '
   BEGIN {
   # File containing configutation data
   CFG_FILE="";

   #
   # GLOBAL index names used for bulding the _prefix_ of the URL.
   # These names _must_ map the "GLOB" field names specified in proviso.cfg
   #
   FLD_GLOBprotocol=    "GLOBprotocol"
   FLD_GLOBdvHost=      "GLOBdvHost"
   FLD_GLOBdvPort=      "GLOBdvPort"
   FLD_GLOBdvDB=        "GLOBdvDB"
   FLD_GLOBdvRoot=      "GLOBdvRoot"           
   FLD_GLOBdvFMservlet= "GLOBdvFMservlet"
   #

   # if specified configuration file does NOT exist - exit with an error code.
   if (fileExists(CFGfile) == 0 ) {
      abort=1;
      printf("Error %s: [%s] configuration file not found\n", ARGV[0], CFG_FILE) | "cat 1>&2";
      exit(1);
   }

   # populate the internal array from the value specified in the 
   # configuration file: qullaby.cfg
   #    entries in the config. file are paired and are separated by "|"
   FS=FScfg
   while (getline < CFGfile > 0) {
       # skip comments in the provisioning file
       if ( $0 ~ /^[#].*/ ) continue;
       arrCfg[trim($1)]=trim($2);
   }
   close(CFGfile);

   # reset the field separator for processing of the WebTop passed "QUERY_STRING" to be
   # parsed to build a redirected URL. The separator is "&":
   #          "&<paramName>=<paramValue>&<paramName>=<paramValue>"
   FS=FSdata;
 }
# ------------------------------------------------------------------------
#
# Function to "trim" leading and trailing spaces from a string NOT
# disturbing the "embedded" spaces.
#
function trim(str)
{
      sub("^[ ]*", "", str);
      sub("[ ]*$", "", str);
      return str;
}
# ------------------------------------------------------------------------
#
# Function to test for the existance of a file
#
function fileExists(file)
{
  ret=0;
  if ((getline dummy < file) > 0) {
  # file exists and can be read
      ret = 1;
      close(file);
  }
   return ret;

}

# ------------------------------------------------------------------------
# Print/Output a passed in URL as part of the HTML block
#
function doHTML(URL) {
   print "Content-type: text/html"
   print "\n"
   print "<html>"
   print "<head>"
   printf("<meta http-equiv=\"Refresh\" content=\"0;url=%s\">\n", URL);
   print "</head>"
   print "</html>"
}
# ------------------------------------------------------------------------

##################################
#                                #
#    Main processing body        #
#                                #
##################################

   # The lines to be processed are of the form:
   #          "&<paramName>=<paramValue>&<paramName>=<paramValue>"
{
  # Build the "prefix" of the redirected URL
  # The prefix of the final URL is based on the values of the "GLOB*" fields 
  # defined in the proviso.cfg configuration file.
  #
  URL=arrCfg[FLD_GLOBprotocol] "://" arrCfg[FLD_GLOBdvHost] ":" arrCfg[FLD_GLOBdvPort] "/" arrCfg[FLD_GLOBdvDB]
  URL=URL "/" arrCfg[FLD_GLOBdvRoot] "/" arrCfg[FLD_GLOBdvFMservlet] "?" 

  # iterate through a list of "&<paramName>=<paramValue>&<paramName>=<paramValue>" pairs 
  # building the final URL mapping the fields coming from WebTop"s fields TO
  # the PROVISO internal fields. 
  # The "paramName" names are mapped to the corresponding internal PROVISO parameter 
  # names defined in the qullaby.cfg configuration file.
  #
  for (i=1; i < NF; i++) {
    nvNum=split($i, nvA, FSvalue);
    #printf("name->[%s] value->[%s]\n", substr(nvA[1], index(nvA[1], ".")+1), nvA[2]);
    name=substr(nvA[1], index(nvA[1], ".")+1);
    value=nvA[2];
    if (! (name in arrCfg)) continue;
    else
       dvName=arrCfg[name];
    URL=URL ((i==1) ? "": FS) dvName FSvalue value
  }
    #print URL
    doHTML(URL);
}
' | cat
exit 0
