#!/bin/ksh

# This is a dev/ps utility to execute parts of the dataview installer

INSTALL_LOG=/tmp/dvutil.log
CONFIG_FILE="config.dv"
DVUTIL_CONF=/var/tmp/PvInstall/dvuninstall.cfg

# Get command line options
while getopts "df:" OPTION
do
   case "${OPTION}" in
       d) DEBUG=ON;;
       f) CONFIG_FILE="${OPTARG}";;
   esac
done

shift $(($OPTIND - 1))

# Load functions - expects to be in a directory one down from the functions
RUNPATH=`dirname $0`
RUNPATH="${RUNPATH}/.."
. ${RUNPATH}/functions
. ${RUNPATH}/functions.oracle
. ${RUNPATH}/functions.silverstream

# Load default values, then dvuinstall.cfg (values set at last successful install) over them
SetDefaultValues
ReadPrevConfig
if [ "$?" = "1" ]; then
   using_saved_config=no
   ReadInstallOptions
fi
WriteConfig

trap 'stopdots' EXIT

ACTION=`echo ${1} | tr [A-Z] [a-z]`
case "${ACTION}" in
   backup)     backup_pvr_db;;
   restore)    restore_pvr_db;;
   checktns)   check_sqlnet $ORACLE_HOME
               check_tnsnames $ORACLE_HOME;;
   autoboot)   SetAutoBootSilverStream;;
   agprofile)  ModifyAgprofile;;
   secure)     secure_dataview
               secure_silvermaster;; 
   unsecure)   unsecure_silvermaster
               unsecure_dataview;;
   testpasswd) test_silverstream_passwords;;
   deversion)  remove_versioning;;
   *) echo ""
      echo "Usage: $0 [-df] backup|restore|checktns|autoboot|agprofile|secure|unsecure|testpasswd|deversion"
      echo ""
      echo "           -d          print debug"
      echo "           -f <file>   use config file <file>"
      echo ""
      ;;
esac

